@@ -176,6 +176,111 @@ rmdir /s /q C:\\temp
         finally:
             os.unlink(temp_file)
 
+    def test_sec003_shutdown_false_positives(self) -> None:
+        """Test SEC003 does not flag shutdown in labels, GOTO, or variable names."""
+        content = """@echo off
+rem Test that shutdown in various contexts doesn't trigger false positives
+
+rem -- Label containing shutdown - should NOT flag
+:ShutDown
+echo In shutdown label
+
+rem -- GOTO statement with shutdown label - should NOT flag
+GOTO :ShutDown
+GOTO :Abort-ShutDown
+
+rem -- Another label with shutdown - should NOT flag
+:Abort-Shutdown
+echo Aborting
+
+rem -- Variable name containing shutdown - should NOT flag
+IF DEFINED @MSSHUTDOWN echo Variable defined
+SET @MSSHUTDOWN=TRUE
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            sec003_issues = [issue for issue in issues if issue.rule.code == "SEC003"]
+            # Should have NO SEC003 issues - all are false positive contexts
+            assert len(sec003_issues) == 0, (
+                f"Expected no SEC003 issues but found {len(sec003_issues)}: "
+                f"{[issue.line_number for issue in sec003_issues]}"
+            )
+        finally:
+            os.unlink(temp_file)
+
+    def test_sec003_shutdown_true_positives(self) -> None:
+        """Test SEC003 correctly flags actual shutdown commands."""
+        content = """@echo off
+rem Test that actual shutdown commands are flagged
+
+rem -- Actual SHUTDOWN command - SHOULD flag
+START "Shutdown" SHUTDOWN -s -f -m \\\\SERVER -t 75 -c "Emergency"
+
+rem -- PSSHUTDOWN command - SHOULD flag
+START "Shutdown" PSSHUTDOWN -k -f -t 75 -m "Emergency" \\\\SERVER
+
+rem -- Abort shutdown - SHOULD flag
+SHUTDOWN -a -m \\\\SERVER
+
+rem -- PSSHUTDOWN abort - SHOULD flag
+PSSHUTDOWN -a \\\\SERVER
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            sec003_issues = [issue for issue in issues if issue.rule.code == "SEC003"]
+            # Should have 4 SEC003 issues - one for each actual command
+            assert len(sec003_issues) == 4, (
+                f"Expected 4 SEC003 issues but found {len(sec003_issues)}: "
+                f"lines {[issue.line_number for issue in sec003_issues]}"
+            )
+        finally:
+            os.unlink(temp_file)
+
+    def test_sec003_where_dangerous_commands(self) -> None:
+        """Test SEC003 flags WHERE with dangerous commands in command substitution."""
+        content = """@echo off
+rem Test that WHERE with dangerous commands is flagged even in SET statements
+
+rem -- WHERE SHUTDOWN in FOR loop - SHOULD flag
+SET @MSSHUTDOWN=& FOR /F %%V IN ('WHERE SHUTDOWN 2^>NUL') DO SET @MSSHUTDOWN=TRUE
+
+rem -- WHERE FORMAT - SHOULD flag
+SET @HASFORMAT=& FOR /F %%V IN ('WHERE FORMAT 2^>NUL') DO SET @HASFORMAT=TRUE
+
+rem -- WHERE DEL - SHOULD flag
+SET @HASDEL=& FOR /F %%V IN ('WHERE DEL 2^>NUL') DO SET @HASDEL=TRUE
+
+rem -- WHERE RMDIR - SHOULD flag
+SET @HASRMDIR=& FOR /F %%V IN ('WHERE RMDIR 2^>NUL') DO SET @HASRMDIR=TRUE
+
+rem -- WHERE PSSHUTDOWN - SHOULD flag
+SET @HASPSSHUTDOWN=& FOR /F %%V IN ('WHERE PSSHUTDOWN 2^>NUL') DO SET @HASPSSHUTDOWN=TRUE
+
+rem -- WHERE REG - SHOULD flag
+SET @HASREG=& FOR /F %%V IN ('WHERE REG 2^>NUL') DO SET @HASREG=TRUE
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            sec003_issues = [issue for issue in issues if issue.rule.code == "SEC003"]
+            # Should have 6 SEC003 issues - one for each WHERE command
+            assert len(sec003_issues) == 6, (
+                f"Expected 6 SEC003 issues for WHERE commands but found {len(sec003_issues)}: "
+                f"lines {[issue.line_number for issue in sec003_issues]}"
+            )
+            # Verify each dangerous command is detected
+            contexts = [issue.context for issue in sec003_issues]
+            assert any("SHUTDOWN" in ctx for ctx in contexts), "Should detect WHERE SHUTDOWN"
+            assert any("FORMAT" in ctx for ctx in contexts), "Should detect WHERE FORMAT"
+            assert any("DEL" in ctx for ctx in contexts), "Should detect WHERE DEL"
+            assert any("RMDIR" in ctx for ctx in contexts), "Should detect WHERE RMDIR"
+            assert any("PSSHUTDOWN" in ctx for ctx in contexts), "Should detect WHERE PSSHUTDOWN"
+            assert any("REG" in ctx for ctx in contexts), "Should detect WHERE REG"
+        finally:
+            os.unlink(temp_file)
+
     def test_long_lines(self) -> None:
         """Test detection of lines exceeding 150 characters."""
         long_line = "echo " + "x" * 155  # Exceed 150 character limit
@@ -407,7 +512,7 @@ echo Process finished
             elif "format" in pattern:
                 test_content = "@echo off\nformat c:\n"
             elif "shutdown" in pattern:
-                test_content = "@echo off\nshutdown\n"
+                test_content = "@echo off\nshutdown /s\n"
             elif "rmdir" in pattern:
                 test_content = "@echo off\nrmdir /s /q C:\\\n"
             else:
@@ -684,7 +789,7 @@ echo Escaped ^> character
         test_cases = [
             (r"del\s+\*/\*|\*\.?\*", ["del *.*", "DEL */*"]),
             (r"format\s+[a-z]:", ["format c:", "format a:", "format d:"]),
-            (r"shutdown", ["shutdown", "SHUTDOWN", "shutdown /s"]),
+            (r"\b(ps)?shutdown\s+[/-]", ["shutdown /s", "SHUTDOWN -t", "psshutdown /a"]),
             (r"rmdir\s+/s\s+/q\s+", ["rmdir /s /q temp", "RMDIR /S /Q folder"]),
         ]
 
@@ -1845,6 +1950,96 @@ net start servicename
         finally:
             os.unlink(temp_file)
 
+    def test_net_command_in_comments_not_flagged(self) -> None:
+        """Test that NET commands in comments are not flagged as requiring privileges."""
+        content = """@ECHO OFF
+REM This script used to use NET VIEW to enumerate computers
+:: We replaced NET VIEW with ADFIND
+::: First we used NET VIEW, then we moved to NETDOM, but now we use ADFIND
+ECHO Script completed
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            rule_codes = [issue.rule.code for issue in issues]
+            sec005_issues = [i for i in issues if i.rule.code == "SEC005"]
+            # NET commands in comments should NOT trigger SEC005
+            assert "SEC005" not in rule_codes, (
+                f"NET commands in comments should NOT be flagged, "
+                f"but got: {[i.context for i in sec005_issues]}"
+            )
+        finally:
+            os.unlink(temp_file)
+
+    def test_net_command_in_set_statement_not_flagged(self) -> None:
+        """Test that NET commands in SET statements are not flagged as requiring privileges."""
+        content = """@ECHO OFF
+SET @ESSENTIAL=PRODUKEY NET PSINFO UPTIME2 SRVINFO
+SET TOOLS=NET USER NET VIEW NET STOP
+SET @UTILS=NETDOM NLTEST REPADMIN
+ECHO Script completed
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            rule_codes = [issue.rule.code for issue in issues]
+            sec005_issues = [i for i in issues if i.rule.code == "SEC005"]
+            # NET commands in SET statements should NOT trigger SEC005
+            assert "SEC005" not in rule_codes, (
+                f"NET commands in SET statements should NOT be flagged, "
+                f"but got: {[i.context for i in sec005_issues]}"
+            )
+        finally:
+            os.unlink(temp_file)
+
+    def test_net_command_in_echo_not_flagged(self) -> None:
+        """Test that NET commands in ECHO statements are not flagged as requiring privileges."""
+        content = """@ECHO OFF
+ECHO Use NET VIEW to list computers
+ECHO Or use NET USER to manage users
+@ECHO NET STOP servicename will stop a service
+ECHO Script completed
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            rule_codes = [issue.rule.code for issue in issues]
+            sec005_issues = [i for i in issues if i.rule.code == "SEC005"]
+            # NET commands in ECHO statements should NOT trigger SEC005
+            assert "SEC005" not in rule_codes, (
+                f"NET commands in ECHO statements should NOT be flagged, "
+                f"but got: {[i.context for i in sec005_issues]}"
+            )
+        finally:
+            os.unlink(temp_file)
+
+    def test_actual_net_command_still_flagged(self) -> None:
+        """Test that actual NET commands outside safe contexts are still flagged."""
+        content = """@ECHO OFF
+NET VIEW \\\\computer
+NET USER username password /add
+ECHO Script completed
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            sec005_issues = [i for i in issues if i.rule.code == "SEC005"]
+            # Actual NET commands should still trigger SEC005
+            assert (
+                len(sec005_issues) >= 2
+            ), f"Expected at least 2 SEC005 issues, got {len(sec005_issues)}"
+            # Check that both NET commands are flagged
+            net_view_flagged = any(
+                "NET command" in i.context for i in sec005_issues if i.line_number == 2
+            )
+            net_user_flagged = any(
+                "NET command" in i.context for i in sec005_issues if i.line_number == 3
+            )
+            assert net_view_flagged, "NET VIEW on line 2 should be flagged"
+            assert net_user_flagged, "NET USER on line 3 should be flagged"
+        finally:
+            os.unlink(temp_file)
+
     def test_deprecated_and_removed_commands_comprehensive(self) -> None:
         """Test comprehensive check of multiple deprecated and removed commands in one file."""
         content = """@ECHO OFF
@@ -2150,3 +2345,94 @@ EXIT /b 0
             assert len(s017_issues) > 0
         finally:
             os.unlink(temp_file)
+
+    def test_s019_magic_numbers_in_set_not_flagged(self) -> None:
+        """Test S019: Numbers in SET statements should not be flagged as magic numbers."""
+        content = """@ECHO OFF
+SET @NMAP_TIME=00:30:00
+SET @SHORT_TIME=00:10:00
+SET @COREINFO_TIME=00:30:00
+SET @MAX_RUN_TIME=01:00:00
+SET @PRIME_LIMIT=1000000000
+SET @JOBTIME=06:01:00
+SET @MAX_SPAWN_TIME=00:02:00
+SET @CODEPAGE_OEM=437
+SET @CODEPAGE_BWCC=65001
+SET /A RESULT=12345
+EXIT /b 0
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            # Should NOT detect any S019 issues - these are constant definitions
+            s019_issues = [i for i in issues if i.rule.code == "S019"]
+            assert len(s019_issues) == 0, f"Found unexpected S019 issues: {s019_issues}"
+        finally:
+            os.unlink(temp_file)
+
+    def test_s019_magic_numbers_in_other_contexts_flagged(self) -> None:
+        """Test S019: Numbers in contexts other than SET statements should be flagged."""
+        content = """@ECHO OFF
+TIMEOUT /T 3600
+PING -n 1234 localhost
+IF %ERRORLEVEL% EQU 5678 GOTO error
+CALL :function 9999
+EXIT /b 0
+:function
+EXIT /b 0
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            # Should detect magic numbers in command arguments
+            s019_issues = [i for i in issues if i.rule.code == "S019"]
+            # Should flag 1234, 5678, 9999 (3600 is in common_exceptions as seconds in an hour)
+            assert len(s019_issues) >= 3, f"Expected at least 3 S019 issues, got {len(s019_issues)}"
+        finally:
+            os.unlink(temp_file)
+
+    def test_s019_magic_numbers_mixed_contexts(self) -> None:
+        """Test S019: Mixed contexts - SET statements and other uses."""
+        content = """@ECHO OFF
+SET @TIMEOUT=3600
+TIMEOUT /T 7200
+SET @RETRIES=1234
+PING -n 5678 localhost
+EXIT /b 0
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            # Should detect magic numbers only in TIMEOUT and PING commands
+            s019_issues = [i for i in issues if i.rule.code == "S019"]
+            # Should flag 7200 and 5678, but NOT 3600 or 1234 (they're in SET)
+            assert (
+                len(s019_issues) == 2
+            ), f"Expected 2 S019 issues, got {len(s019_issues)}: {s019_issues}"
+            # Verify the flagged line numbers
+            flagged_lines = {issue.line_number for issue in s019_issues}
+            assert 3 in flagged_lines  # TIMEOUT line
+            assert 5 in flagged_lines  # PING line
+        finally:
+            os.unlink(temp_file)
+
+    def test_s019_set_statements_in_if_blocks(self) -> None:
+        """Test S019: SET statements inside IF blocks should not flag numbers."""
+        content = """@ECHO OFF
+IF "%1"=="test" (
+    SET @TIMEOUT=3600
+    SET @RETRIES=1234
+) ELSE (
+    SET @TIMEOUT=7200
+)
+IF "%2"=="quick" (SET @DELAY=30) ELSE (SET @DELAY=300)
+EXIT /b 0
+"""
+        temp_file = self.create_temp_batch_file(content)
+        try:
+            issues = lint_batch_file(temp_file)
+            # Should NOT detect any S019 issues - all numbers are in SET statements
+            s019_issues = [i for i in issues if i.rule.code == "S019"]
+            assert len(s019_issues) == 0, f"Found unexpected S019 issues: {s019_issues}"
+        finally:
+            os.unlink(temp_file)
