@@ -5,12 +5,14 @@ import io
 import queue
 import sys
 import threading
-from typing import Callable, List, Union
+from typing import Callable, List, Optional, Tuple, Union
 
 from blinter import (
     RULES,
     LintIssue,
     RuleSeverity,
+    _display_analyzed_scripts,
+    _format_line_numbers_with_files,
     group_issues,
     print_detailed,
     print_help,
@@ -141,7 +143,7 @@ class TestPrintFunctions:
         output = self.capture_stdout(print_detailed, issues)
 
         assert "DETAILED ISSUES:" in output
-        assert "No issues found! ?" in output
+        assert "No issues found! *" in output
 
     def test_print_detailed_with_issues(self) -> None:
         """Test detailed output with issues."""
@@ -241,8 +243,8 @@ class TestOutputFormatting:
         output = self.capture_stdout(print_severity_info, issues)
         assert "2 issues" in output
 
-    def test_line_number_formatting(self) -> None:
-        """Test proper formatting of line numbers in detailed output."""
+    def test_line_number_formatting_single_file(self) -> None:
+        """Test proper formatting of line numbers in detailed output for single file."""
         issues = [
             self.create_lint_issue(1, "W005"),
             self.create_lint_issue(3, "W005"),
@@ -255,6 +257,58 @@ class TestOutputFormatting:
         # Should have comma-separated, sorted line numbers
         assert "Line 1, 3, 5, 7: Unquoted variable with spaces (W005)" in output
 
+    def test_line_number_formatting_multi_file(self) -> None:
+        """Test proper formatting of line numbers in detailed output for multiple files."""
+        issues = [
+            LintIssue(line_number=197, rule=RULES["W039"], file_path="DriveInfo.BAT"),
+            LintIssue(line_number=245, rule=RULES["W039"], file_path="DriveInfo.BAT"),
+            LintIssue(line_number=529, rule=RULES["W039"], file_path="SetDrive.BAT"),
+            LintIssue(line_number=564, rule=RULES["W039"], file_path="SetDrive.BAT"),
+            LintIssue(line_number=440, rule=RULES["W039"], file_path="StorageInfo.BAT"),
+            LintIssue(line_number=643, rule=RULES["W039"], file_path="StorageInfo.BAT"),
+        ]
+
+        output = self.capture_stdout(print_detailed, issues)
+
+        # Should have hierarchical format with file grouping
+        assert "Nested FOR loops without call optimization (W039)" in output
+        assert "[DriveInfo.BAT] Line 197, 245" in output
+        assert "[SetDrive.BAT] Line 529, 564" in output
+        assert "[StorageInfo.BAT] Line 440, 643" in output
+        # Should not have the old format
+        assert "Line 197 [DriveInfo.BAT]" not in output
+
+    def test_format_line_numbers_with_files_single_file(self) -> None:
+        """Test _format_line_numbers_with_files for single file."""
+        issues = [
+            self.create_lint_issue(1, "W005"),
+            self.create_lint_issue(3, "W005"),
+            self.create_lint_issue(5, "W005"),
+        ]
+
+        is_multi_file, line_data = _format_line_numbers_with_files(issues)
+
+        assert is_multi_file is False
+        assert line_data == "Line 1, 3, 5"
+
+    def test_format_line_numbers_with_files_multi_file(self) -> None:
+        """Test _format_line_numbers_with_files for multiple files."""
+        issues = [
+            LintIssue(line_number=100, rule=RULES["W039"], file_path="script1.bat"),
+            LintIssue(line_number=200, rule=RULES["W039"], file_path="script1.bat"),
+            LintIssue(line_number=50, rule=RULES["W039"], file_path="script2.bat"),
+            LintIssue(line_number=150, rule=RULES["W039"], file_path="script2.bat"),
+        ]
+
+        is_multi_file, line_data = _format_line_numbers_with_files(issues)
+
+        assert is_multi_file is True
+        assert isinstance(line_data, dict)
+        assert "script1.bat" in line_data
+        assert "script2.bat" in line_data
+        assert line_data["script1.bat"] == [100, 200]
+        assert line_data["script2.bat"] == [50, 150]
+
     def test_special_characters_in_output(self) -> None:
         """Test handling of special characters in error messages and context."""
         issues = [
@@ -382,3 +436,85 @@ class TestOutputFormatting:
             "Most common issue: 'Inconsistent command capitalization' "
             "(S003) - 3 occurrences" in output
         )
+
+
+class TestDisplayAnalyzedScripts:
+    """Test cases for the _display_analyzed_scripts function."""
+
+    def capture_stdout(
+        self, func: Callable[[List[Tuple[str, Optional[str]]], str, bool], None], *args: object
+    ) -> str:
+        """Helper method to capture stdout output."""
+        old_stdout = sys.stdout
+        sys.stdout = captured_output = io.StringIO()
+        try:
+            func(*args)
+            return captured_output.getvalue()
+        finally:
+            sys.stdout = old_stdout
+
+    def test_display_single_script(self) -> None:
+        """Test displaying a single analyzed script."""
+        processed_files = [("D:\\test\\script.bat", None)]
+        target_path = "D:\\test"
+
+        output = self.capture_stdout(_display_analyzed_scripts, processed_files, target_path, False)
+
+        assert "Scripts Analyzed:" in output
+        assert "1. script.bat" in output
+
+    def test_display_multiple_scripts(self) -> None:
+        """Test displaying multiple analyzed scripts."""
+        processed_files = [
+            ("D:\\test\\main.bat", None),
+            ("D:\\test\\utils.bat", None),
+            ("D:\\test\\config.cmd", None),
+        ]
+        target_path = "D:\\test"
+
+        output = self.capture_stdout(_display_analyzed_scripts, processed_files, target_path, True)
+
+        assert "Scripts Analyzed:" in output
+        assert "1. main.bat" in output
+        assert "2. utils.bat" in output
+        assert "3. config.cmd" in output
+
+    def test_display_called_scripts_with_parent(self) -> None:
+        """Test displaying called scripts with parent information."""
+        processed_files = [
+            ("D:\\test\\main.bat", None),
+            ("D:\\test\\config.bat", "D:\\test\\main.bat"),
+            ("D:\\test\\other.bat", None),
+        ]
+        target_path = "D:\\test"
+
+        output = self.capture_stdout(_display_analyzed_scripts, processed_files, target_path, True)
+
+        assert "Scripts Analyzed:" in output
+        assert "1. main.bat" in output
+        assert "2.   ↳ config.bat (called by main.bat)" in output
+        assert "3. other.bat" in output
+
+    def test_display_empty_list(self) -> None:
+        """Test displaying with no processed files."""
+        processed_files: list[tuple[str, Union[str, None]]] = []
+        target_path = "D:\\test"
+
+        output = self.capture_stdout(_display_analyzed_scripts, processed_files, target_path, False)
+
+        # Should output nothing for empty list
+        assert output == ""
+
+    def test_display_scripts_relative_path_directory(self) -> None:
+        """Test displaying scripts with relative paths in directory mode."""
+        processed_files = [
+            ("D:\\test\\subdir\\script.bat", None),
+            ("D:\\test\\main.bat", None),
+        ]
+        target_path = "D:\\test"
+
+        output = self.capture_stdout(_display_analyzed_scripts, processed_files, target_path, True)
+
+        assert "Scripts Analyzed:" in output
+        assert "subdir" in output or "subdir\\script.bat" in output
+        # Should show relative paths in directory mode
